==> aptechka-0.44.1.tgz: package/lib/canvas/index.js <==
var S = (i) => {
  throw TypeError(i);
};
var x = (i, s, e) => s.has(i) || S("Cannot " + e);
var t = (i, s, e) => (x(i, s, "read from private field"), e ? e.call(i) : s.get(i)), h = (i, s, e) => s.has(i) ? S("Cannot add the same private member more than once") : s instanceof WeakSet ? s.add(i) : s.set(i, e), a = (i, s, e, p) => (x(i, s, "write to private field"), p ? p.call(i, e) : s.set(i, e), e), c = (i, s, e) => (x(i, s, "access private method"), e);
import { CSSProperty as z } from "../css-property/index.js";
import { elementResizer as C } from "../element-resizer/index.js";
import { ticker as w } from "../ticker/index.js";
import { i as y } from "../index-euf5anj6.js";
import { c as B } from "../jss-BQSxj7Ls.js";
import { c as F } from "../math-BOBiC4TN.js";
var o, r, d, m, l, u, b, f, n, R, k, g, v, E, P;
class L extends HTMLElement {
  constructor() {
    super();
    h(this, n);
    h(this, o, new z(this, "--fps", 0));
    h(this, r, null);
    h(this, d, null);
    h(this, m, 0);
    h(this, l, 0);
    h(this, u, 1);
    h(this, b, 0);
    h(this, f, 1);
    h(this, g, (e) => {
      a(this, u, F(devicePixelRatio, 1, 2)), a(this, m, e.contentRect.width), a(this, l, e.contentRect.height), t(this, r).width = t(this, m) * this.pixelRatio, t(this, r).height = t(this, l) * this.pixelRatio, this.context.scale(this.pixelRatio, this.pixelRatio), c(this, n, P).call(this), c(this, n, E).call(this);
    });
    h(this, v, (e) => {
      a(this, b, e.timestamp), a(this, f, e.timeBetweenFrames), c(this, n, E).call(this);
    });
    if (y) {
      const e = this.attachShadow({ mode: "open" });
      e.adoptedStyleSheets = [
        B({
          " :host, canvas": {
            display: "block",
            width: "100%",
            height: "100%"
          }
        })
      ], a(this, r, document.createElement("canvas")), a(this, d, t(this, r).getContext("2d")), e.appendChild(t(this, r)), t(this, o).subscribe((p) => {
        typeof p.previous != "undefined" && p.current !== p.previous && c(this, n, R).call(this);
      });
    }
  }
  get fpsCSSProperty() {
    return t(this, o);
  }
  get canvasElement() {
    return t(this, r);
  }
  get context() {
    return t(this, d);
  }
  get pixelRatio() {
    return t(this, u);
  }
  get width() {
    return t(this, m);
  }
  get height() {
    return t(this, l);
  }
  get detail() {
    return {
      width: t(this, m),
      height: t(this, l),
      element: this,
      canvasElement: t(this, r),
      pixelRatio: t(this, u),
      context: t(this, d),
      timestamp: t(this, b),
      timeBetweenFrames: t(this, f)
    };
  }
  connectedCallback() {
    t(this, o).observe(), C.subscribe(this, t(this, g)), c(this, n, R).call(this);
  }
  disconnectedCallback() {
    t(this, o).unobserve(), C.unsubscribe(t(this, g)), c(this, n, k).call(this);
  }
}
o = new WeakMap(), r = new WeakMap(), d = new WeakMap(), m = new WeakMap(), l = new WeakMap(), u = new WeakMap(), b = new WeakMap(), f = new WeakMap(), n = new WeakSet(), R = function() {
  w.unsubscribe(t(this, v)), this.hasAttribute("static") || w.subscribe(t(this, v), {
    culling: this,
    maxFPS: t(this, o).current
  });
}, k = function() {
  w.unsubscribe(t(this, v));
}, g = new WeakMap(), v = new WeakMap(), E = function() {
  this.dispatchEvent(
    new CustomEvent("canvasRender", {
      composed: !0,
      detail: this.detail
    })
  );
}, P = function() {
  this.dispatchEvent(
    new CustomEvent("canvasResize", {
      composed: !0,
      detail: this.detail
    })
  );
};
y && !customElements.get("e-canvas") && customElements.define("e-canvas", L);
export {
  L as CanvasElement
};

==> aptechka-0.49.0.tgz: package/lib/canvas/index.js <==
var S = (i) => {
  throw TypeError(i);
};
var x = (i, s, e) => s.has(i) || S("Cannot " + e);
var t = (i, s, e) => (x(i, s, "read from private field"), e ? e.call(i) : s.get(i)), h = (i, s, e) => s.has(i) ? S("Cannot add the same private member more than once") : s instanceof WeakSet ? s.add(i) : s.set(i, e), a = (i, s, e, p) => (x(i, s, "write to private field"), p ? p.call(i, e) : s.set(i, e), e), c = (i, s, e) => (x(i, s, "access private method"), e);
import { CSSProperty as z } from "../css-property/index.js";
import { elementResizer as C } from "../element-resizer/index.js";
import { ticker as w } from "../ticker/index.js";
import { i as y } from "../index-euf5anj6.js";
import { c as B } from "../jss-Chm3yE5y.js";
import { c as F } from "../math-BOBiC4TN.js";
var o, r, d, m, l, u, b, f, n, R, k, g, v, E, P;
class L extends HTMLElement {
  constructor() {
    super();
    h(this, n);
    h(this, o, new z(this, "--fps", 0));
    h(this, r, null);
    h(this, d, null);
    h(this, m, 0);
    h(this, l, 0);
    h(this, u, 1);
    h(this, b, 0);
    h(this, f, 1);
    h(this, g, (e) => {
      a(this, u, F(devicePixelRatio, 1, 2)), a(this, m, e.contentRect.width), a(this, l, e.contentRect.height), t(this, r).width = t(this, m) * this.pixelRatio, t(this, r).height = t(this, l) * this.pixelRatio, this.context.scale(this.pixelRatio, this.pixelRatio), c(this, n, P).call(this), c(this, n, E).call(this);
    });
    h(this, v, (e) => {
      a(this, b, e.timestamp), a(this, f, e.timeBetweenFrames), c(this, n, E).call(this);
    });
    if (y) {
      const e = this.attachShadow({ mode: "open" });
      e.adoptedStyleSheets = [
        B({
          " :host, canvas": {
            display: "block",
            width: "100%",
            height: "100%"
          }
        })
      ], a(this, r, document.createElement("canvas")), a(this, d, t(this, r).getContext("2d")), e.appendChild(t(this, r)), t(this, o).subscribe((p) => {
        typeof p.previous != "undefined" && p.current !== p.previous && c(this, n, R).call(this);
      });
    }
  }
  get fpsCSSProperty() {
    return t(this, o);
  }
  get canvasElement() {
    return t(this, r);
  }
  get context() {
    return t(this, d);
  }
  get pixelRatio() {
    return t(this, u);
  }
  get width() {
    return t(this, m);
  }
  get height() {
    return t(this, l);
  }
  get detail() {
    return {
      width: t(this, m),
      height: t(this, l),
      element: this,
      canvasElement: t(this, r),
      pixelRatio: t(this, u),
      context: t(this, d),
      timestamp: t(this, b),
      timeBetweenFrames: t(this, f)
    };
  }
  connectedCallback() {
    t(this, o).observe(), C.subscribe(this, t(this, g)), c(this, n, R).call(this);
  }
  disconnectedCallback() {
    t(this, o).unobserve(), C.unsubscribe(t(this, g)), c(this, n, k).call(this);
  }
}
o = new WeakMap(), r = new WeakMap(), d = new WeakMap(), m = new WeakMap(), l = new WeakMap(), u = new WeakMap(), b = new WeakMap(), f = new WeakMap(), n = new WeakSet(), R = function() {
  w.unsubscribe(t(this, v)), this.hasAttribute("static") || w.subscribe(t(this, v), {
    culling: this,
    maxFPS: t(this, o).current
  });
}, k = function() {
  w.unsubscribe(t(this, v));
}, g = new WeakMap(), v = new WeakMap(), E = function() {
  this.dispatchEvent(
    new CustomEvent("canvasRender", {
      composed: !0,
      detail: this.detail
    })
  );
}, P = function() {
  this.dispatchEvent(
    new CustomEvent("canvasResize", {
      composed: !0,
      detail: this.detail
    })
  );
};
y && !customElements.get("e-canvas") && customElements.define("e-canvas", L);
export {
  L as CanvasElement
};
